@@ -455,9 +455,9 @@ class GroupManager(BaseManager, ChartMixin):
         except Exception, exc:
             # TODO: should we mail admins when there are failures?
             try:
-                logger.exception(u'Unable to process log entry: %s' % (exc,))
+                logger.exception(u'Unable to process log entry: %s', exc)
             except Exception, exc:
-                warnings.warn(u'Unable to process log entry: %s' % (exc,))
+                warnings.warn(u'Unable to process log entry: %s', exc)
 
             return
 
@@ -802,6 +802,75 @@ class InstanceMetaManager(BaseManager):
         self._metadata = {}
 
 
+class UserOptionManager(BaseManager):
+    NOTSET = object()
+
+    def __init__(self, *args, **kwargs):
+        super(UserOptionManager, self).__init__(*args, **kwargs)
+        request_finished.connect(self.clear_cache)
+
+    def get_value(self, user, project, key, default=NOTSET):
+        result = self.get_all_values(user, project)
+        if default is self.NOTSET:
+            return result[key]
+        return result.get(key, default)
+
+    def unset_value(self, user, project, key):
+        self.filter(user=user, project=project, key=key).delete()
+        if not hasattr(self, '_metadata'):
+            return
+        if project:
+            metakey = (user.pk, project.pk)
+        else:
+            metakey = (user.pk, None)
+        if metakey not in self._metadata:
+            return
+        self._metadata[metakey].pop(key, None)
+
+    def set_value(self, user, project, key, value):
+        inst, created = self.get_or_create(
+            user=user,
+            project=project,
+            key=key,
+            defaults={
+                'value': value,
+            },
+        )
+        if not created and inst.value != value:
+            inst.update(value=value)
+
+        if not hasattr(self, '_metadata'):
+            return
+        if project:
+            metakey = (user.pk, project.pk)
+        else:
+            metakey = (user.pk, None)
+        if metakey not in self._metadata:
+            return
+        self._metadata[metakey][key] = value
+
+    def get_all_values(self, user, project):
+        if not hasattr(self, '_metadata'):
+            self._metadata = {}
+        if project:
+            metakey = (user.pk, project.pk)
+        else:
+            metakey = (user.pk, None)
+        if metakey not in self._metadata:
+            result = dict(
+                (i.key, i.value) for i in
+                self.filter(
+                    user=user,
+                    project=project,
+                )
+            )
+            self._metadata[metakey] = result
+        return self._metadata[metakey]
+
+    def clear_cache(self, **kwargs):
+        self._metadata = {}
+
+
 class SearchDocumentManager(BaseManager):
     # Words which should not be indexed
     STOP_WORDS = set(['the', 'of', 'to', 'and', 'a', 'in', 'is', 'it', 'you', 'that'])
@@ -837,6 +906,12 @@ class SearchDocumentManager(BaseManager):
         else:
             raise ValueError('sort_by: %r' % sort_by)
 
+        if tokens:
+            token_sql = ' st.token IN (%s) AND ' % \
+                ', '.join('%s' for i in range(len(tokens)))
+        else:
+            token_sql = ' '
+
         sql = """
             SELECT sd.id AS id,
                    sd.group_id AS group_id,
@@ -846,13 +921,13 @@ class SearchDocumentManager(BaseManager):
             FROM sentry_searchdocument as sd
             INNER JOIN sentry_searchtoken as st
                 ON st.document_id = sd.id
-            WHERE st.token IN (%s)
-                AND sd.project_id = %s
+            WHERE %s
+                sd.project_id = %s
             GROUP BY sd.id, sd.group_id, sd.total_events, sd.date_changed, sd.date_added
             ORDER BY %s
             LIMIT %d OFFSET %d
         """ % (
-            ', '.join('%s' for i in range(len(tokens))),
+            token_sql,
             project.id,
             order_by,
             limit,
